Fair-Scoring
============

Fairness metrics for continuous risk scores.

The implemented algorithms are described in the paper [Becker2024]_.

References
----------
.. [Becker2024] Becker, A.K. and Dumitrasc, O. and Broelemann, K.;
   Standardized Interpretable Fairness Measures for Continuous Risk Scores;
   Proceedings of the 41th International Conference on Machine Learning, 2024;

Table of Content
================

.. toctree::
   :maxdepth: 2

   intro
   examples
   autoapi/index
   changelog



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

